@@ -91,21 +91,21 @@ def coco_det_demo():
     # re = det.format_output(lang="zh")
 
 def face_det_demo():
-    img = 'face2.jpeg' # 指定进行推理的图片路径
+    img = 'banniang.jpg' # 指定进行推理的图片路径
     # img = 'face2.jpeg' # 指定进行推理的图片路径
 
     det = wf(task='det_face' )
     face = wf(task="pose_face")
 
-    result,img = det.inference(data=img,img_type='cv2') # 在CPU上进行推理
+    result,img = det.inference(data=img,img_type='cv2',scaleFactor=1.4,minNeighbors=8) # 在CPU上进行推理
     re =  det.format_output(lang="zh")
 
     det.show(img)
-    for i in result:
-        ky,img = face.inference(data=img, img_type="cv2",bbox=i)#,erase=False)
-        face.show(img)
+    # det.save(img,"banniang1.jpg")
+    # for i in result:
+    #     ky,img = face.inference(data=img, img_type="cv2",bbox=i)#,erase=False)
+    #     face.show(img)
     
-    re =  det.format_output(lang="zh")
 
 def ocr_demo():
     img = 'ocr.jpg' # 指定进行推理的图片路径
@@ -119,15 +119,19 @@ def ocr_demo():
     re = ocr.format_output(lang="zh")
 
 def mmedu_demo():
-
     mm = wf(task='mmedu',checkpoint="det_fire.onnx")
     result, img = mm.inference(data='fire.jpg',img_type='pil',thr=0.6)
-    mm.show(img)
-    print(result)
+    # mm.show(img)
+    # print(result)
+    re = mm.format_output(lang="zh")
+
+    mm = wf(task='mmedu',checkpoint="convert_model.onnx")
+    result, img = mm.inference(data='fire.jpg',img_type='pil',thr=0.6)
+    # mm.show(img)
+    # print(result)
     re = mm.format_output(lang="zh")
 
 def basenn_demo():
-
     nn = wf(task='basenn',checkpoint="checkpoints/basenn.onnx") # iris act 
     result,img = nn.inference(data='6.jpg',img_type='cv2')
     re = nn.format_output(lang="zh")
@@ -267,9 +271,12 @@ def drive_demo():
     # drp.save(image,"demo_ou.jpg")
 
 def embedding_demo():
+    # 导入依赖库
     from XEdu.hub import Workflow as wf
     from XEdu.utils import get_similarity
+    # 实例化图像嵌入模型
     img_emb = wf(task='embedding_image')
+    # 实例化文本嵌入模型
     text_emb = wf(task='embedding_text')
     images = ["cat.jpg"]
     texts_zh = ["猫", "狗"]
@@ -283,8 +290,109 @@ def embedding_demo():
     logits = get_similarity(text_en_embeddings,text_zh_embeddings) # ,method='cosine',use_softmax=False)
     print("cosine", logits)
 
+    # 导入依赖库
+    from XEdu.hub import Workflow as wf
+    from XEdu.utils import get_similarity
+    # 实例化图像嵌入模型
+    img_emb = wf(task='embedding_image')
+    # 实例化文本嵌入模型
+    text_emb = wf(task='embedding_text')
+    # 示例输入
+    images = ["cat.jpg"]
+    texts = ["猫", "狗"]
+    # 对图像进行编码
+    image_embeddings = img_emb.inference(data=images)
+    # 对文本进行编码
+    text_embeddings = text_emb.inference(data=texts)
+    # 计算相似度
+    similarity = get_similarity(image_embeddings,text_embeddings,method='cosine')
+
+
+def openvino_demo():
+    import openvino as ov 
+    from openvino.runtime import Core
+    ie = Core()
+    devices = ie.available_devices
+
+    for device in devices:
+        device_name = ie.get_property(device,'FULL_DEVICE_NAME')
+        print(f'{device}:{device_name}')
+
+    from openvino.runtime import Core
+
+    ie =  Core()
+    model_xml = './checkpoints/body17.onnx'
+
+    model  = ie.read_model(model=model_xml)
+    compiled_model = ie.compile_model(model=model,device_name='CPU')
+
+
+    input_layer = compiled_model.input(0)
+    output_layer = compiled_model.output(0)
+
+    import cv2
+    import numpy as np
+
+    image_filename = "pose1.jpg"
+    image = cv2.imread(image_filename)
+    image.shape
+
+    # N,C,H,W = batch size, number of channels, height, width.
+    N, C, H, W = input_layer.shape
+    # OpenCV resize expects the destination size as (width, height).
+    resized_image = cv2.resize(src=image, dsize=(W, H))
+    resized_image.shape
+
+    input_data = np.expand_dims(np.transpose(resized_image, (2, 0, 1)), 0).astype(np.float32)
+    input_data.shape
+
+
+    # for single input models only
+    result = compiled_model(input_data)[output_layer]
+
+    # for multiple inputs in a list
+    result = compiled_model([input_data])[output_layer]
+
+    # or using a dictionary, where the key is input tensor name or index
+    result = compiled_model({input_layer.any_name: input_data})[output_layer]
+
+    print(result)
+
+def openvino_demo():
+    import openvino as ov 
+    from openvino.runtime import Core
+
+    import cv2
+    import numpy as np
+
+    ie =  Core()
+    model_xml = './checkpoints/body17.onnx'
+
+    model  = ie.read_model(model=model_xml)
+    compiled_model = ie.compile_model(model=model,device_name='CPU')
+
+
+    input_layer = compiled_model.input(0)
+    output_layer = compiled_model.output(0)
+
+    image_filename = "pose1.jpg"
+    image = cv2.imread(image_filename)
+
+    # N,C,H,W = batch size, number of channels, height, width.
+    N, C, H, W = input_layer.shape
+    resized_image = cv2.resize(src=image, dsize=(W, H))
+
+    input_data = np.expand_dims(np.transpose(resized_image, (2, 0, 1)), 0).astype(np.float32)
+
+
+    # for single input models only
+    result = compiled_model(input_data)[output_layer]
+
+    print(result)
+
+
 if __name__ == "__main__":
-    pose_infer_demo()
+    # pose_infer_demo()
     # det_infer_demo()
     # video_infer_demo()
     # hand_video_demo()
@@ -292,7 +400,7 @@ if __name__ == "__main__":
     # hand_det_demo()
     # face_det_demo()
     # ocr_demo()
-    # mmedu_demo()
+    mmedu_demo()
     # custom_demo()
     # basenn_demo()
     # cls_demo()
@@ -300,4 +408,7 @@ if __name__ == "__main__":
     # style_demo()
     # qa_demo()
     # drive_demo()
-    # embedding_demo()
\ No newline at end of file
+    # embedding_demo()
+ 
+
+    
\ No newline at end of file
