@@ -18,6 +18,9 @@ from .tokenizer.qa_tokenizer import *
 from .tokenizer.qa_squadprocess import *
 from .tokenizer.clip_tokenizer import Preprocessor, Tokenizer
 from .datatset_class import coco_class,imagenet_class
+import copy
+
+from .errorcode import ErrorCodeFactory as ecf
 T = TypeVar("T")
 
 def to_batches(items: Iterable[T], size: int) -> Iterator[List[T]]:
@@ -79,6 +82,40 @@ task_dict = {
 style_list = ['mosaic','candy','rain-princess','udnie','pointilism']
 
 class Workflow:
+    """
+        Workflow类用于加载预训练模型以解决各类任务。
+        目前支持的任务有：
+            - pose_body17：人体关键点检测，17个关键点
+            - pose_body17_l：人体关键点检测，17个关键点，模型更大
+            - pose_body26：人体关键点检测，26个关键点
+            - pose_wholebody133：全身关键点检测，包括人体、人脸和手部共133个关键点
+            - pose_face106：人脸关键点检测，106个关键点
+            - pose_hand21：手部关键点检测，21个关键点
+            - det_body：人体检测
+            - det_body_l：人体检测，模型更大
+            - det_coco：物体检测，80类，基于COCO数据集
+            - det_coco_l：物体检测，基于COCO数据集，模型更大
+            - det_hand：手部检测
+            - det_face：人脸检测
+            - cls_imagenet：图像分类，1000类，基于ImageNet数据集
+            - gen_style：风格迁移，5种风格
+            - nlp_qa：问答系统，基于SQuAD数据集
+            - drive_perception：全景驾驶感知系统，包括交通对象检测、可行驶道路区域分割和车道检测任务
+            - embedding_image：CLIP图像嵌入
+            - embedding_text：CLIP文本嵌入   
+            - ocr：光学字符识别，基于rapidocr
+            - mmedu：MMEdu模型推理
+            - basenn：BaseNN模型推理
+            - baseml：BaseML模型推理
+
+
+        Attributes:
+            task：任务类型，可选范围如以上列出。    
+            checkpoint：模型权重文件的路径。
+            download_path：模型文件即将下载到的路径。
+
+        更多用法及算法详解请参考：https://xedu.readthedocs.io/zh/master/xedu_hub/introduction.html    
+    """
     @classmethod
     def support_task(cls):
         return list(task_dict.keys())
@@ -206,12 +243,18 @@ class Workflow:
             if checkpoint is None:
                 print("请先指定通过MMEdu导出的onnx模型路径。")
                 return
+            assert os.path.exists(checkpoint),ecf.NO_SUCH_CHECKPOINT(checkpoint)
+            assert os.path.splitext(checkpoint)[-1]==".onnx",ecf.CHECKPOINT_TYPE(os.path.splitext(checkpoint)[-1].strip("."))
+
             from .BaseDeploy import _BaseDeploy as bd
             self.model = bd(checkpoint)
         elif self.task == 'baseml':
             if checkpoint is None:
                 print("请先指定通过BaseML导出的pkl模型路径。")
                 return
+            assert os.path.exists(checkpoint),ecf.NO_SUCH_CHECKPOINT(checkpoint)
+            assert os.path.splitext(checkpoint)[-1]==".pkl",ecf.CHECKPOINT_TYPE(os.path.splitext(checkpoint)[-1].strip("."))
+
             try:
                 import sklearn
                 import joblib
@@ -219,9 +262,9 @@ class Workflow:
                 os.system("pip install scikit-learn")
                 import joblib
             self.model = joblib.load(checkpoint)
-
-
         else:
+            assert os.path.exists(checkpoint),ecf.NO_SUCH_CHECKPOINT(checkpoint)
+            assert os.path.splitext(checkpoint)[-1]==".onnx",ecf.CHECKPOINT_TYPE(os.path.splitext(checkpoint)[-1].strip("."))
             self.model = ort.InferenceSession(checkpoint, None)
         print(f"{self.task}任务模型加载成功！")
     
@@ -229,6 +272,12 @@ class Workflow:
     def inference(self,data=None,show=False,img_type=None,thr=0.3,bbox=None,target_class=None,erase=False,preprocess=None, postprocess=None,**kwargs):
         self._get_img = img_type
         self.erase=erase
+        if isinstance(data,str) and self.task not in ['nlp_qa','embedding_text']:
+            assert os.path.exists(data),ecf.NO_SUCH_FILE(data)
+            filetype = ['.jpg','.png','.jpeg','.jiff']
+            assert os.path.splitext(data.lower())[-1] in filetype,ecf.INFER_DATA_TYPE(os.path.splitext(data)[-1].strip("."))
+
+
         if self.task in ["pose_body17","pose_body26","pose_face106","pose_hand21","pose_wholebody133","pose_body17_l"]:
             return self._pose_infer(data,show,img_type,bbox)
         elif self.task in['det_body','det_coco','det_hand','det_body_l','det_coco_l']:
@@ -446,8 +495,7 @@ class Workflow:
             doc = read_squad_examples_context(input_data=context)
         else:
             if self.doc is None:
-                print("Please load_context before inference !")
-                return
+                raise Exception(ecf.LOAD_CONTEXT_BEFORE_INFER())
             doc = self.doc
             self.contexts.append(self.context)
 
@@ -759,7 +807,7 @@ class Workflow:
         if isinstance(data,str):
             image = cv2.imread(data)
         else:
-            image = data
+            image = copy.copy(data)
         ### 推理
         face_model = self.model
    
@@ -822,7 +870,7 @@ class Workflow:
             # image = Image.open(data)
             image = cv2.imread(data)
         else:
-            image = data
+            image = copy.copy(data)
             # image = Image.fromarray(data)
         # image = Image.open(img_path).resize((224,224))  # 这里设置的动态数据尺寸，不需要resize
         re_image =cv2.resize(image,(224,224))
@@ -961,7 +1009,7 @@ class Workflow:
         if isinstance(self.data,str):
             img = cv2.imread((self.data))
         else:
-            img = self.data
+            img = copy.copy(self.data)
         h,w,c = img.shape
         sketch_scale = max(1,(min(h,w)/ 100))
 
@@ -1003,8 +1051,7 @@ class Workflow:
             plt.imshow(img)
             plt.show()
         except:
-            print("Error: please inference before show.")
-            pass
+            raise Exception(ecf.INFER_BEFORE_SHOW())
     
     def save(self,img,save_path): # check
         if self._get_img == 'cv2':
